==> coil-core-android-3.0.4-sources.jar: androidMain/coil3/imageLoaders.android.kt <==
package coil3

import android.graphics.BitmapFactory
import android.graphics.ImageDecoder
import coil3.decode.BitmapFactoryDecoder
import coil3.decode.BitmapFactoryDecoder.Companion.DEFAULT_MAX_PARALLELISM
import coil3.decode.ExifOrientationStrategy
import coil3.decode.ExifOrientationStrategy.Companion.RESPECT_PERFORMANCE

// region bitmapFactoryMaxParallelism

/**
 * Sets the maximum number of parallel [BitmapFactory] or [ImageDecoder] decode operations at once.
 *
 * Increasing this number will allow more parallel decode operations, however it can result in
 * worse UI performance.
 */
fun ImageLoader.Builder.bitmapFactoryMaxParallelism(maxParallelism: Int) = apply {
    require(maxParallelism > 0) { "maxParallelism must be > 0." }
    extras[bitmapFactoryMaxParallelismKey] = maxParallelism
}

internal val RealImageLoader.Options.bitmapFactoryMaxParallelism: Int
    get() = defaults.extras.getOrDefault(bitmapFactoryMaxParallelismKey)

private val bitmapFactoryMaxParallelismKey = Extras.Key(default = DEFAULT_MAX_PARALLELISM)

// endregion
// region bitmapFactoryExifOrientationStrategy

/**
 * Sets the strategy for handling the EXIF orientation flag for images decoded by
 * [BitmapFactoryDecoder].
 */
fun ImageLoader.Builder.bitmapFactoryExifOrientationStrategy(strategy: ExifOrientationStrategy) = apply {
    extras[bitmapFactoryExifOrientationStrategyKey] = strategy
}

internal val RealImageLoader.Options.bitmapFactoryExifOrientationStrategy: ExifOrientationStrategy
    get() = defaults.extras.getOrDefault(bitmapFactoryExifOrientationStrategyKey)

private val bitmapFactoryExifOrientationStrategyKey = Extras.Key(default = RESPECT_PERFORMANCE)

// endregion

==> coil-core-android-3.2.0-sources.jar: androidMain/coil3/imageLoaders.android.kt <==
package coil3

import android.graphics.BitmapFactory
import android.graphics.ImageDecoder
import coil3.decode.BitmapFactoryDecoder
import coil3.decode.BitmapFactoryDecoder.Companion.DEFAULT_MAX_PARALLELISM
import coil3.decode.Decoder
import coil3.decode.ExifOrientationStrategy
import coil3.decode.ExifOrientationStrategy.Companion.RESPECT_PERFORMANCE

// region bitmapFactoryMaxParallelism

/**
 * Sets the maximum number of parallel [BitmapFactory] or [ImageDecoder] decode operations at once.
 *
 * Increasing this number will allow more parallel decode operations, however it can result in
 * worse UI performance.
 */
fun ImageLoader.Builder.bitmapFactoryMaxParallelism(maxParallelism: Int) = apply {
    require(maxParallelism > 0) { "maxParallelism must be > 0." }
    extras[bitmapFactoryMaxParallelismKey] = maxParallelism
}

internal val RealImageLoader.Options.bitmapFactoryMaxParallelism: Int
    get() = defaults.extras.getOrDefault(bitmapFactoryMaxParallelismKey)

private val bitmapFactoryMaxParallelismKey = Extras.Key(default = DEFAULT_MAX_PARALLELISM)

// endregion
// region bitmapFactoryExifOrientationStrategy

/**
 * Sets the strategy for handling the EXIF orientation flag for images decoded by
 * [BitmapFactoryDecoder].
 */
fun ImageLoader.Builder.bitmapFactoryExifOrientationStrategy(strategy: ExifOrientationStrategy) = apply {
    extras[bitmapFactoryExifOrientationStrategyKey] = strategy
}

internal val RealImageLoader.Options.bitmapFactoryExifOrientationStrategy: ExifOrientationStrategy
    get() = defaults.extras.getOrDefault(bitmapFactoryExifOrientationStrategyKey)

private val bitmapFactoryExifOrientationStrategyKey = Extras.Key(default = RESPECT_PERFORMANCE)

// endregion
// region imageDecoderEnabled

/**
 * Enables using [ImageDecoder] as this image loader's main [Decoder] on API 29 and above.
 * If false, [BitmapFactory] is used on all API levels.
 */
fun ImageLoader.Builder.imageDecoderEnabled(enabled: Boolean) = apply {
    extras[imageDecoderEnabledKey] = enabled
}

internal val RealImageLoader.Options.imageDecoderEnabled: Boolean
    get() = defaults.extras.getOrDefault(imageDecoderEnabledKey)

private val imageDecoderEnabledKey = Extras.Key(default = true)

// endregion
